@@ -743,15 +743,23 @@ void SDocumentsWriter<T>::ThreadState::resetPostings() {
 
 template<typename T>
 int32_t SDocumentsWriter<T>::ThreadState::comparePostings(Posting *p1, Posting *p2) {
-    if constexpr (std::is_same_v<T, char>) {
-        auto n1 = p1->term_.size();
-        auto n2 = p2->term_.size();
-        auto min = std::min(n1, n2);
-        auto s1 = p1->term_.data();
-        auto s2 = p2->term_.data();
-        return StringUtil::string_compare(s1, n1, s2, n2, min);
-    } else {
-        return p1->term_.compare(p2->term_);
+    const T *pos1 = scharPool->buffers[p1->textStart >> CHAR_BLOCK_SHIFT] + (p1->textStart & CHAR_BLOCK_MASK);
+    const T *pos2 = scharPool->buffers[p2->textStart >> CHAR_BLOCK_SHIFT] + (p2->textStart & CHAR_BLOCK_MASK);
+    while (true) {
+        const auto c1 = static_cast<typename std::make_unsigned<T>::type>(*pos1++);
+        const auto c2 = static_cast<typename std::make_unsigned<T>::type>(*pos2++);
+        if (c1 < c2)
+            if (CLUCENE_END_OF_WORD == c2)
+                return 1;
+            else
+                return -1;
+        else if (c2 < c1)
+            if (CLUCENE_END_OF_WORD == c1)
+                return -1;
+            else
+                return 1;
+        else if (CLUCENE_END_OF_WORD == c1)
+            return 0;
     }
 }
 
