@@ -42,6 +42,7 @@
 #include "olap/rowset/segment_v2/inverted_index_desc.h"
 #include "olap/tablet_schema.h"
 #include "olap/utils.h"
+#include "util/debug_points.h"
 #include "util/doris_metrics.h"
 
 namespace doris {
@@ -232,21 +233,40 @@ Status BetaRowset::link_files_to(const std::string& dir, RowsetId new_rowset_id,
     if (fs->type() != io::FileSystemType::LOCAL) {
         return Status::InternalError("should be local file system");
     }
+
+    Status status;
+    std::vector<string> linked_success_files;
+    Defer remove_linked_files {[&]() { // clear linked files if errors happen
+        if (!status.ok()) {
+            LOG(WARNING) << "will delete linked success files due to error " << status;
+            std::vector<io::Path> paths;
+            for (auto& file : linked_success_files) {
+                paths.emplace_back(file);
+                LOG(WARNING) << "will delete linked success file " << file << " due to error";
+            }
+            static_cast<void>(fs->batch_delete(paths));
+            LOG(WARNING) << "done delete linked success files due to error " << status;
+        }
+    }};
+
     io::LocalFileSystem* local_fs = (io::LocalFileSystem*)fs.get();
     for (int i = 0; i < num_segments(); ++i) {
         auto dst_path = segment_file_path(dir, new_rowset_id, i + new_rowset_start_seg_id);
         bool dst_path_exist = false;
         if (!fs->exists(dst_path, &dst_path_exist).ok() || dst_path_exist) {
-            return Status::Error<FILE_ALREADY_EXIST>(
+            status = Status::Error<FILE_ALREADY_EXIST>(
                     "failed to create hard link, file already exist: {}", dst_path);
+            return status;
         }
         auto src_path = segment_file_path(i);
         // TODO(lingbin): how external storage support link?
         //     use copy? or keep refcount to avoid being delete?
         if (!local_fs->link_file(src_path, dst_path).ok()) {
-            return Status::Error<OS_ERROR>("fail to create hard link. from={}, to={}, errno={}",
-                                           src_path, dst_path);
+            status = Status::Error<OS_ERROR>("fail to create hard link. from={}, to={}, errno={}",
+                                             src_path, dst_path, Errno::no());
+            return status;
         }
+        linked_success_files.push_back(dst_path);
         for (auto& index : _schema->indexes()) {
             if (index.index_type() != IndexType::INVERTED) {
                 continue;
@@ -260,25 +280,31 @@ Status BetaRowset::link_files_to(const std::string& dir, RowsetId new_rowset_id,
                     InvertedIndexDescriptor::get_index_file_name(src_path, index_id);
             std::string inverted_index_dst_file_path =
                     InvertedIndexDescriptor::get_index_file_name(dst_path, index_id);
-            bool need_to_link = true;
-            if (_schema->skip_write_index_on_load()) {
-                local_fs->exists(inverted_index_src_file_path, &need_to_link);
-                if (!need_to_link) {
-                    LOG(INFO) << "skip create hard link to not existed file="
-                              << inverted_index_src_file_path;
-                }
-            }
-            if (need_to_link) {
+            bool index_file_exists = true;
+            RETURN_IF_ERROR(local_fs->exists(inverted_index_src_file_path, &index_file_exists));
+            if (index_file_exists) {
+                DBUG_EXECUTE_IF(
+                        "fault_inject::BetaRowset::link_files_to::_link_inverted_index_file", {
+                            status = Status::Error<OS_ERROR>(
+                                    "fault_inject link_file error from={}, to={}",
+                                    inverted_index_src_file_path, inverted_index_dst_file_path);
+                            return status;
+                        });
                 if (!local_fs->link_file(inverted_index_src_file_path, inverted_index_dst_file_path)
                              .ok()) {
-                    return Status::Error<OS_ERROR>(
+                    status = Status::Error<OS_ERROR>(
                             "fail to create hard link. from={}, to={}, errno={}",
                             inverted_index_src_file_path, inverted_index_dst_file_path,
                             Errno::no());
+                    return status;
                 }
+                linked_success_files.push_back(inverted_index_dst_file_path);
                 LOG(INFO) << "success to create hard link. from=" << inverted_index_src_file_path
                           << ", "
                           << "to=" << inverted_index_dst_file_path;
+            } else {
+                LOG(WARNING) << "skip create hard link to not existed index file="
+                             << inverted_index_src_file_path;
             }
         }
     }
@@ -286,7 +312,7 @@ Status BetaRowset::link_files_to(const std::string& dir, RowsetId new_rowset_id,
 }
 
 Status BetaRowset::copy_files_to(const std::string& dir, const RowsetId& new_rowset_id) {
-    if (is_local() && num_segments() > 0) [[unlikely]] {
+    if (!is_local() && num_segments() > 0) [[unlikely]] {
         DCHECK(false) << rowset_id();
         return Status::NotSupported("cannot copy remote files, rowset_id={}",
                                     rowset_id().to_string());
