@@ -73,6 +73,7 @@
 #include "util/bit_util.h"
 #include "util/brpc_client_cache.h"
 #include "util/cpu_info.h"
+#include "util/dns_cache.h"
 #include "util/doris_metrics.h"
 #include "util/mem_info.h"
 #include "util/metrics.h"
@@ -169,6 +170,7 @@ Status ExecEnv::_init(const std::vector<StorePath>& store_paths) {
     _block_spill_mgr = new BlockSpillManager(_store_paths);
     _file_meta_cache = new FileMetaCache(config::max_external_file_meta_cache_num);
 
+    _dns_cache = new DNSCache();
     _backend_client_cache->init_metrics("backend");
     _frontend_client_cache->init_metrics("frontend");
     _broker_client_cache->init_metrics("broker");
@@ -384,6 +386,7 @@ void ExecEnv::_destroy() {
     if (!_is_init) {
         return;
     }
+
     _deregister_metrics();
     SAFE_DELETE(_internal_client_cache);
     SAFE_DELETE(_function_client_cache);
@@ -425,6 +428,9 @@ void ExecEnv::_destroy() {
     InvertedIndexSearcherCache::reset_global_instance();
 
     SAFE_DELETE(_runtime_query_statistics_mgr);
+
+    // dns cache is a global instance and need to be released at last
+    SAFE_DELETE(_dns_cache);
     _is_init = false;
 }
 
