@@ -17,27 +17,32 @@
 
 #include "util/url_parser.h"
 
+#include <ctype.h>
+#include <stdint.h>
+
+#include <algorithm>
 #include <string>
 
-#include "runtime/string_value.hpp"
+#include "runtime/string_search.hpp"
+#include "vec/common/string_ref.h"
 
 namespace doris {
 
-const StringValue UrlParser::_s_url_authority(const_cast<char*>("AUTHORITY"), 9);
-const StringValue UrlParser::_s_url_file(const_cast<char*>("FILE"), 4);
-const StringValue UrlParser::_s_url_host(const_cast<char*>("HOST"), 4);
-const StringValue UrlParser::_s_url_path(const_cast<char*>("PATH"), 4);
-const StringValue UrlParser::_s_url_protocol(const_cast<char*>("PROTOCOL"), 8);
-const StringValue UrlParser::_s_url_query(const_cast<char*>("QUERY"), 5);
-const StringValue UrlParser::_s_url_ref(const_cast<char*>("REF"), 3);
-const StringValue UrlParser::_s_url_userinfo(const_cast<char*>("USERINFO"), 8);
-const StringValue UrlParser::_s_url_port(const_cast<char*>("PORT"), 4);
-const StringValue UrlParser::_s_protocol(const_cast<char*>("://"), 3);
-const StringValue UrlParser::_s_at(const_cast<char*>("@"), 1);
-const StringValue UrlParser::_s_slash(const_cast<char*>("/"), 1);
-const StringValue UrlParser::_s_colon(const_cast<char*>(":"), 1);
-const StringValue UrlParser::_s_question(const_cast<char*>("?"), 1);
-const StringValue UrlParser::_s_hash(const_cast<char*>("#"), 1);
+const StringRef UrlParser::_s_url_authority(const_cast<char*>("AUTHORITY"), 9);
+const StringRef UrlParser::_s_url_file(const_cast<char*>("FILE"), 4);
+const StringRef UrlParser::_s_url_host(const_cast<char*>("HOST"), 4);
+const StringRef UrlParser::_s_url_path(const_cast<char*>("PATH"), 4);
+const StringRef UrlParser::_s_url_protocol(const_cast<char*>("PROTOCOL"), 8);
+const StringRef UrlParser::_s_url_query(const_cast<char*>("QUERY"), 5);
+const StringRef UrlParser::_s_url_ref(const_cast<char*>("REF"), 3);
+const StringRef UrlParser::_s_url_userinfo(const_cast<char*>("USERINFO"), 8);
+const StringRef UrlParser::_s_url_port(const_cast<char*>("PORT"), 4);
+const StringRef UrlParser::_s_protocol(const_cast<char*>("://"), 3);
+const StringRef UrlParser::_s_at(const_cast<char*>("@"), 1);
+const StringRef UrlParser::_s_slash(const_cast<char*>("/"), 1);
+const StringRef UrlParser::_s_colon(const_cast<char*>(":"), 1);
+const StringRef UrlParser::_s_question(const_cast<char*>("?"), 1);
+const StringRef UrlParser::_s_hash(const_cast<char*>("#"), 1);
 const StringSearch UrlParser::_s_protocol_search(&_s_protocol);
 const StringSearch UrlParser::_s_at_search(&_s_at);
 const StringSearch UrlParser::_s_slash_search(&_s_slash);
@@ -45,11 +50,11 @@ const StringSearch UrlParser::_s_colon_search(&_s_colon);
 const StringSearch UrlParser::_s_question_search(&_s_question);
 const StringSearch UrlParser::_s_hash_search(&_s_hash);
 
-bool UrlParser::parse_url(const StringValue& url, UrlPart part, StringValue* result) {
-    result->ptr = nullptr;
-    result->len = 0;
+bool UrlParser::parse_url(const StringRef& url, UrlPart part, StringRef* result) {
+    result->data = nullptr;
+    result->size = 0;
     // Remove leading and trailing spaces.
-    StringValue trimmed_url = url.trim();
+    StringRef trimmed_url = url.trim();
 
     // All parts require checking for the _s_protocol.
     int32_t protocol_pos = _s_protocol_search.search(&trimmed_url);
@@ -58,7 +63,7 @@ bool UrlParser::parse_url(const StringValue& url, UrlPart part, StringValue* res
     }
 
     // Positioned to first char after '://'.
-    StringValue protocol_end = trimmed_url.substring(protocol_pos + _s_protocol.len);
+    StringRef protocol_end = trimmed_url.substring(protocol_pos + _s_protocol.size);
 
     switch (part) {
     case AUTHORITY: {
@@ -78,7 +83,7 @@ bool UrlParser::parse_url(const StringValue& url, UrlPart part, StringValue* res
             return true;
         }
 
-        StringValue path_start = protocol_end.substring(start_pos);
+        StringRef path_start = protocol_end.substring(start_pos);
         int32_t end_pos;
 
         if (part == FILE) {
@@ -107,10 +112,15 @@ bool UrlParser::parse_url(const StringValue& url, UrlPart part, StringValue* res
             start_pos = 0;
         } else {
             // Skip '@'.
-            start_pos += _s_at.len;
+            start_pos += _s_at.size;
         }
 
-        StringValue host_start = protocol_end.substring(start_pos);
+        StringRef host_start = protocol_end.substring(start_pos);
+        // Find first '?'.
+        int32_t query_start_pos = _s_question_search.search(&host_start);
+        if (query_start_pos > 0) {
+            host_start = host_start.substring(0, query_start_pos);
+        }
         // Find ':' to strip out port.
         int32_t end_pos = _s_colon_search.search(&host_start);
 
@@ -137,7 +147,7 @@ bool UrlParser::parse_url(const StringValue& url, UrlPart part, StringValue* res
             return false;
         }
 
-        StringValue query_start = protocol_end.substring(start_pos + _s_question.len);
+        StringRef query_start = protocol_end.substring(start_pos + _s_question.size);
         // End string _s_at next '#'.
         int32_t end_pos = _s_hash_search.search(&query_start);
         *result = query_start.substring(0, end_pos);
@@ -153,7 +163,7 @@ bool UrlParser::parse_url(const StringValue& url, UrlPart part, StringValue* res
             return false;
         }
 
-        *result = protocol_end.substring(start_pos + _s_hash.len);
+        *result = protocol_end.substring(start_pos + _s_hash.size);
         break;
     }
 
@@ -179,10 +189,10 @@ bool UrlParser::parse_url(const StringValue& url, UrlPart part, StringValue* res
             start_pos = 0;
         } else {
             // Skip '@'.
-            start_pos += _s_at.len;
+            start_pos += _s_at.size;
         }
 
-        StringValue host_start = protocol_end.substring(start_pos);
+        StringRef host_start = protocol_end.substring(start_pos);
         // Find ':' to strip out port.
         int32_t end_pos = _s_colon_search.search(&host_start);
         //no port found
@@ -190,7 +200,7 @@ bool UrlParser::parse_url(const StringValue& url, UrlPart part, StringValue* res
             return false;
         }
 
-        StringValue port_start_str = protocol_end.substring(end_pos + _s_colon.len);
+        StringRef port_start_str = protocol_end.substring(end_pos + _s_colon.size);
         int32_t port_end_pos = _s_slash_search.search(&port_start_str);
         //if '/' not found, try to find '?'
         if (port_end_pos < 0) {
@@ -207,20 +217,20 @@ bool UrlParser::parse_url(const StringValue& url, UrlPart part, StringValue* res
     return true;
 }
 
-bool UrlParser::parse_url_key(const StringValue& url, UrlPart part, const StringValue& key,
-                              StringValue* result) {
+bool UrlParser::parse_url_key(const StringRef& url, UrlPart part, const StringRef& key,
+                              StringRef* result) {
     // Part must be query to ask for a specific query key.
     if (part != QUERY) {
         return false;
     }
 
     // Remove leading and trailing spaces.
-    StringValue trimmed_url = url.trim();
+    StringRef trimmed_url = url.trim();
 
     // Search for the key in the url, ignoring malformed URLs for now.
     StringSearch key_search(&key);
 
-    while (trimmed_url.len > 0) {
+    while (trimmed_url.size > 0) {
         // Search for the key in the current substring.
         int32_t key_pos = key_search.search(&trimmed_url);
         bool match = true;
@@ -232,31 +242,31 @@ bool UrlParser::parse_url_key(const StringValue& url, UrlPart part, const String
         // Key pos must be != 0 because it must be preceded by a '?' or a '&'.
         // Check that the char before key_pos is either '?' or '&'.
         if (key_pos == 0 ||
-            (trimmed_url.ptr[key_pos - 1] != '?' && trimmed_url.ptr[key_pos - 1] != '&')) {
+            (trimmed_url.data[key_pos - 1] != '?' && trimmed_url.data[key_pos - 1] != '&')) {
             match = false;
         }
 
         // Advance substring beyond matching key.
-        trimmed_url = trimmed_url.substring(key_pos + key.len);
+        trimmed_url = trimmed_url.substring(key_pos + key.size);
 
         if (!match) {
             continue;
         }
 
-        if (trimmed_url.len <= 0) {
+        if (trimmed_url.size <= 0) {
             break;
         }
 
         // Next character must be '=', otherwise the match cannot be a key in the query part.
-        if (trimmed_url.ptr[0] != '=') {
+        if (trimmed_url.data[0] != '=') {
             continue;
         }
 
         int32_t pos = 1;
 
         // Find ending position of key's value by matching '#' or '&'.
-        while (pos < trimmed_url.len) {
-            switch (trimmed_url.ptr[pos]) {
+        while (pos < trimmed_url.size) {
+            switch (trimmed_url.data[pos]) {
             case '#':
             case '&':
                 *result = trimmed_url.substring(1, pos - 1);
@@ -274,13 +284,13 @@ bool UrlParser::parse_url_key(const StringValue& url, UrlPart part, const String
     return false;
 }
 
-UrlParser::UrlPart UrlParser::get_url_part(const StringValue& part) {
+UrlParser::UrlPart UrlParser::get_url_part(const StringRef& part) {
     // Quick filter on requested URL part, based on first character.
     // Hive requires the requested URL part to be all upper case.
     std::string part_str = part.to_string();
     transform(part_str.begin(), part_str.end(), part_str.begin(), ::toupper);
-    StringValue newPart = StringValue(part_str);
-    switch (newPart.ptr[0]) {
+    StringRef newPart = StringRef(part_str);
+    switch (newPart.data[0]) {
     case 'A': {
         if (!newPart.eq(_s_url_authority)) {
             return INVALID;
@@ -346,10 +356,10 @@ UrlParser::UrlPart UrlParser::get_url_part(const StringValue& part) {
     }
 }
 
-StringValue UrlParser::extract_url(StringValue url, StringValue name) {
-    StringValue result("", 0);
+StringRef UrlParser::extract_url(StringRef url, StringRef name) {
+    StringRef result("", 0);
     // Remove leading and trailing spaces.
-    StringValue trimmed_url = url.trim();
+    StringRef trimmed_url = url.trim();
     // find '?'
     int32_t question_pos = _s_question_search.search(&trimmed_url);
     if (question_pos < 0) {
@@ -360,9 +370,9 @@ StringValue UrlParser::extract_url(StringValue url, StringValue name) {
 
     // find '#'
     int32_t hash_pos = _s_hash_search.search(&trimmed_url);
-    StringValue sub_url;
+    StringRef sub_url;
     if (hash_pos < 0) {
-        sub_url = trimmed_url.substring(question_pos + 1, trimmed_url.len - question_pos - 1);
+        sub_url = trimmed_url.substring(question_pos + 1, trimmed_url.size - question_pos - 1);
     } else {
         sub_url = trimmed_url.substring(question_pos + 1, hash_pos - question_pos - 1);
     }
@@ -370,8 +380,8 @@ StringValue UrlParser::extract_url(StringValue url, StringValue name) {
     // find '&' and '=', and extract target parameter
     // Example: k1=aa&k2=bb&k3=cc&test=dd
     int64_t and_pod;
-    auto len = sub_url.len;
-    StringValue key_url;
+    auto len = sub_url.size;
+    StringRef key_url;
     while (true) {
         if (len <= 0) {
             break;
@@ -385,14 +395,14 @@ StringValue UrlParser::extract_url(StringValue url, StringValue name) {
             key_url = end_pos == -1 ? sub_url : sub_url.substring(0, end_pos);
             sub_url = result;
         }
-        len = sub_url.len;
+        len = sub_url.size;
 
         auto eq_pod = key_url.find_first_of('=');
         if (eq_pod == -1) {
             // invalid url. like: k1&k2=bb
             continue;
         }
-        int32_t key_len = key_url.len;
+        int32_t key_len = key_url.size;
         auto key = key_url.substring(0, eq_pod);
         if (name == key) {
             return key_url.substring(eq_pod + 1, key_len - eq_pod - 1);
