@@ -49,7 +49,9 @@
 #include "vec/core/types.h"
 #include "vec/data_types/data_type.h"
 #include "vec/data_types/data_type_number.h" // IWYU pragma: keep
+#include "vec/data_types/number_traits.h"
 #include "vec/data_types/serde/data_type_serde.h"
+#include "vec/utils/template_helpers.hpp"
 
 namespace doris {
 class DecimalV2Value;
@@ -83,36 +85,13 @@ constexpr size_t max_decimal_precision<Decimal64>() {
 }
 template <>
 constexpr size_t max_decimal_precision<Decimal128>() {
-    return 38;
+    return 27;
 }
 template <>
 constexpr size_t max_decimal_precision<Decimal128I>() {
     return 38;
 }
 
-template <typename T>
-constexpr typename T::NativeType max_decimal_value() {
-    return 0;
-}
-template <>
-constexpr Int32 max_decimal_value<Decimal32>() {
-    return 999999999;
-}
-template <>
-constexpr Int64 max_decimal_value<Decimal64>() {
-    return 999999999999999999;
-}
-template <>
-constexpr Int128 max_decimal_value<Decimal128>() {
-    return static_cast<int128_t>(999999999999999999ll) * 100000000000000000ll * 1000ll +
-           static_cast<int128_t>(99999999999999999ll) * 1000ll + 999ll;
-}
-template <>
-constexpr Int128 max_decimal_value<Decimal128I>() {
-    return static_cast<int128_t>(999999999999999999ll) * 100000000000000000ll * 1000ll +
-           static_cast<int128_t>(99999999999999999ll) * 1000ll + 999ll;
-}
-
 DataTypePtr create_decimal(UInt64 precision, UInt64 scale, bool use_v2);
 
 inline UInt32 least_decimal_precision_for(TypeIndex int_type) {
@@ -312,6 +291,8 @@ public:
 
     static T get_scale_multiplier(UInt32 scale);
 
+    static T get_max_digits_number(UInt32 digit_count);
+
     bool parse_from_string(const std::string& str, T* res) const;
 
     static void check_type_precision(const vectorized::UInt32 precision) {
@@ -412,11 +393,14 @@ template <typename DataType>
 constexpr bool IsDataTypeDecimalOrNumber =
         IsDataTypeDecimal<DataType> || IsDataTypeNumber<DataType>;
 
-template <typename FromDataType, typename ToDataType>
+// only for casting between other integral types and decimals
+template <typename FromDataType, typename ToDataType, bool multiply_may_overflow,
+          bool narrow_integral>
     requires IsDataTypeDecimal<FromDataType> && IsDataTypeDecimal<ToDataType>
 ToDataType::FieldType convert_decimals(const typename FromDataType::FieldType& value,
                                        UInt32 scale_from, UInt32 scale_to,
-                                       UInt8* overflow_flag = nullptr) {
+                                       const typename ToDataType::FieldType& min_result,
+                                       const typename ToDataType::FieldType& max_result) {
     using FromFieldType = typename FromDataType::FieldType;
     using ToFieldType = typename ToDataType::FieldType;
     using MaxFieldType =
@@ -426,41 +410,51 @@ ToDataType::FieldType convert_decimals(const typename FromDataType::FieldType& v
                                Decimal128I,
                                std::conditional_t<(sizeof(FromFieldType) > sizeof(ToFieldType)),
                                                   FromFieldType, ToFieldType>>;
-    using MaxNativeType = typename MaxFieldType::NativeType;
 
-    MaxNativeType converted_value;
+    MaxFieldType converted_value;
+    // from integer to decimal
     if (scale_to > scale_from) {
         converted_value =
                 DataTypeDecimal<MaxFieldType>::get_scale_multiplier(scale_to - scale_from);
-        if (common::mul_overflow(static_cast<MaxNativeType>(value), converted_value,
-                                 converted_value)) {
-            if (overflow_flag) {
-                *overflow_flag = 1;
+        if constexpr (multiply_may_overflow) {
+            if (common::mul_overflow(static_cast<MaxFieldType>(value).value, converted_value.value,
+                                     converted_value.value)) {
+                throw Exception(ErrorCode::ARITHMETIC_OVERFLOW_ERRROR, "Arithmetic overflow");
+            } else {
+                if constexpr (narrow_integral) {
+                    if (UNLIKELY(converted_value.value > max_result.value ||
+                                 converted_value.value < min_result.value)) {
+                        throw Exception(ErrorCode::ARITHMETIC_OVERFLOW_ERRROR,
+                                        "Arithmetic overflow");
+                    }
+                }
+            }
+        } else {
+            converted_value *= static_cast<MaxFieldType>(value).value;
+            if constexpr (narrow_integral) {
+                if (UNLIKELY(converted_value.value > max_result.value ||
+                             converted_value.value < min_result.value)) {
+                    throw Exception(ErrorCode::ARITHMETIC_OVERFLOW_ERRROR, "Arithmetic overflow");
+                }
             }
-            VLOG_DEBUG << "Decimal convert overflow";
-            return converted_value < 0
-                           ? std::numeric_limits<typename ToFieldType::NativeType>::min()
-                           : std::numeric_limits<typename ToFieldType::NativeType>::max();
         }
     } else {
+        // from decimal to integer
         converted_value =
-                value / DataTypeDecimal<MaxFieldType>::get_scale_multiplier(scale_from - scale_to);
-    }
-
-    if constexpr (sizeof(FromFieldType) > sizeof(ToFieldType)) {
-        if (converted_value < std::numeric_limits<typename ToFieldType::NativeType>::min()) {
-            if (overflow_flag) {
-                *overflow_flag = 1;
+                static_cast<MaxFieldType>(value) /
+                DataTypeDecimal<MaxFieldType>::get_scale_multiplier(scale_from - scale_to);
+        if (value >= FromFieldType(0)) {
+            if constexpr (narrow_integral) {
+                if (UNLIKELY(converted_value.value > max_result.value)) {
+                    throw Exception(ErrorCode::ARITHMETIC_OVERFLOW_ERRROR, "Arithmetic overflow");
+                }
             }
-            VLOG_DEBUG << "Decimal convert overflow";
-            return std::numeric_limits<typename ToFieldType::NativeType>::min();
-        }
-        if (converted_value > std::numeric_limits<typename ToFieldType::NativeType>::max()) {
-            if (overflow_flag) {
-                *overflow_flag = 1;
+        } else {
+            if constexpr (narrow_integral) {
+                if (UNLIKELY(converted_value.value < min_result.value)) {
+                    throw Exception(ErrorCode::ARITHMETIC_OVERFLOW_ERRROR, "Arithmetic overflow");
+                }
             }
-            VLOG_DEBUG << "Decimal convert overflow";
-            return std::numeric_limits<typename ToFieldType::NativeType>::max();
         }
     }
 
@@ -472,8 +466,8 @@ void convert_decimal_cols(
         const typename ColumnDecimal<
                 typename FromDataType::FieldType>::Container::value_type* __restrict vec_from,
         typename ColumnDecimal<typename ToDataType::FieldType>::Container::value_type* vec_to,
-        const UInt32 scale_from, const UInt32 scale_to, const size_t sz,
-        UInt8* overflow_flag = nullptr) {
+        const UInt32 precision_from, const UInt32 scale_from, const UInt32 precision_to,
+        const UInt32 scale_to, const size_t sz) {
     using FromFieldType = typename FromDataType::FieldType;
     using ToFieldType = typename ToDataType::FieldType;
     using MaxFieldType =
@@ -485,64 +479,103 @@ void convert_decimal_cols(
                                                   FromFieldType, ToFieldType>>;
     using MaxNativeType = typename MaxFieldType::NativeType;
 
+    auto max_result = DataTypeDecimal<ToFieldType>::get_max_digits_number(precision_to);
+    bool narrow_integral = (precision_to - scale_to) < (precision_from - scale_from);
     if (scale_to > scale_from) {
         const MaxNativeType multiplier =
                 DataTypeDecimal<MaxFieldType>::get_scale_multiplier(scale_to - scale_from);
         MaxNativeType res;
-        for (size_t i = 0; i < sz; i++) {
-            if (std::is_same_v<MaxNativeType, Int128>) {
-                if (common::mul_overflow(static_cast<MaxNativeType>(vec_from[i]), multiplier,
-                                         res)) {
-                    if (overflow_flag) {
-                        overflow_flag[i] = 1;
+        auto from_max_digits = NumberTraits::max_ascii_len<typename FromFieldType::NativeType>();
+        auto to_max_digits = NumberTraits::max_ascii_len<typename ToFieldType::NativeType>();
+        bool multiply_may_overflow = (from_max_digits + scale_to - scale_from) > to_max_digits;
+        std::visit(
+                [&](auto multiply_may_overflow, auto narrow_integral) {
+                    for (size_t i = 0; i < sz; i++) {
+                        if constexpr (multiply_may_overflow) {
+                            if (common::mul_overflow(static_cast<MaxNativeType>(vec_from[i].value),
+                                                     multiplier, res)) {
+                                throw Exception(ErrorCode::ARITHMETIC_OVERFLOW_ERRROR,
+                                                "Arithmetic overflow");
+                            } else {
+                                if (UNLIKELY(res > max_result.value || res < -max_result.value)) {
+                                    throw Exception(ErrorCode::ARITHMETIC_OVERFLOW_ERRROR,
+                                                    "Arithmetic overflow");
+                                } else {
+                                    vec_to[i] = ToFieldType(res);
+                                }
+                            }
+                        } else {
+                            res = vec_from[i].value * multiplier;
+                            if constexpr (narrow_integral) {
+                                if (UNLIKELY(res > max_result.value || res < -max_result.value)) {
+                                    throw Exception(ErrorCode::ARITHMETIC_OVERFLOW_ERRROR,
+                                                    "Arithmetic overflow");
+                                }
+                            }
+                            vec_to[i] = ToFieldType(res);
+                        }
                     }
-                    VLOG_DEBUG << "Decimal convert overflow";
-                    vec_to[i] =
-                            res < 0 ? std::numeric_limits<typename ToFieldType::NativeType>::min()
-                                    : std::numeric_limits<typename ToFieldType::NativeType>::max();
-                } else {
-                    vec_to[i] = res;
-                }
-            } else {
-                vec_to[i] = vec_from[i] * multiplier;
-            }
-        }
+                },
+                make_bool_variant(multiply_may_overflow), make_bool_variant(narrow_integral));
+    } else if (scale_to == scale_from) {
+        std::visit(
+                [&](auto narrow_integral) {
+                    for (size_t i = 0; i < sz; i++) {
+                        if constexpr (narrow_integral) {
+                            if (UNLIKELY(vec_from[i].value > max_result.value ||
+                                         vec_from[i].value < -max_result.value)) {
+                                throw Exception(ErrorCode::ARITHMETIC_OVERFLOW_ERRROR,
+                                                "Arithmetic overflow");
+                            }
+                        }
+                        vec_to[i] = ToFieldType(vec_from[i].value);
+                    }
+                },
+                make_bool_variant(narrow_integral));
     } else {
         MaxNativeType multiplier =
                 DataTypeDecimal<MaxFieldType>::get_scale_multiplier(scale_from - scale_to);
-        for (size_t i = 0; i < sz; i++) {
-            if (vec_from[i] >= 0) {
-                vec_to[i] = (vec_from[i] + multiplier / 2) / multiplier;
-            } else {
-                vec_to[i] = (vec_from[i] - multiplier / 2) / multiplier;
-            }
-        }
-    }
-
-    if constexpr (sizeof(FromFieldType) > sizeof(ToFieldType)) {
-        for (size_t i = 0; i < sz; i++) {
-            if (vec_to[i] < std::numeric_limits<typename ToFieldType::NativeType>::min()) {
-                if (overflow_flag) {
-                    *overflow_flag = 1;
-                }
-                VLOG_DEBUG << "Decimal convert overflow";
-                vec_to[i] = std::numeric_limits<typename ToFieldType::NativeType>::min();
-            }
-            if (vec_to[i] > std::numeric_limits<typename ToFieldType::NativeType>::max()) {
-                if (overflow_flag) {
-                    *overflow_flag = 1;
-                }
-                VLOG_DEBUG << "Decimal convert overflow";
-                vec_to[i] = std::numeric_limits<typename ToFieldType::NativeType>::max();
-            }
-        }
+        MaxNativeType res;
+        std::visit(
+                [&](auto narrow_integral) {
+                    for (size_t i = 0; i < sz; i++) {
+                        if (vec_from[i] >= FromFieldType(0)) {
+                            if constexpr (narrow_integral) {
+                                res = (vec_from[i].value + multiplier / 2) / multiplier;
+                                if (UNLIKELY(res > max_result.value)) {
+                                    throw Exception(ErrorCode::ARITHMETIC_OVERFLOW_ERRROR,
+                                                    "Arithmetic overflow");
+                                }
+                                vec_to[i] = ToFieldType(res);
+                            } else {
+                                vec_to[i] = ToFieldType((vec_from[i].value + multiplier / 2) /
+                                                        multiplier);
+                            }
+                        } else {
+                            if constexpr (narrow_integral) {
+                                res = (vec_from[i].value - multiplier / 2) / multiplier;
+                                if (UNLIKELY(res < -max_result.value)) {
+                                    throw Exception(ErrorCode::ARITHMETIC_OVERFLOW_ERRROR,
+                                                    "Arithmetic overflow");
+                                }
+                                vec_to[i] = ToFieldType(res);
+                            } else {
+                                vec_to[i] = ToFieldType((vec_from[i].value - multiplier / 2) /
+                                                        multiplier);
+                            }
+                        }
+                    }
+                },
+                make_bool_variant(narrow_integral));
     }
 }
 
-template <typename FromDataType, typename ToDataType>
+template <typename FromDataType, typename ToDataType, bool narrow_integral>
     requires IsDataTypeDecimal<FromDataType> && IsDataTypeNumber<ToDataType>
 ToDataType::FieldType convert_from_decimal(const typename FromDataType::FieldType& value,
-                                           UInt32 scale) {
+                                           UInt32 scale,
+                                           const typename ToDataType::FieldType& min_result,
+                                           const typename ToDataType::FieldType& max_result) {
     using FromFieldType = typename FromDataType::FieldType;
     using ToFieldType = typename ToDataType::FieldType;
 
@@ -550,84 +583,55 @@ ToDataType::FieldType convert_from_decimal(const typename FromDataType::FieldTyp
         if constexpr (IsDecimalV2<FromFieldType>) {
             return binary_cast<int128_t, DecimalV2Value>(value);
         } else {
-            return static_cast<ToFieldType>(value) / FromDataType::get_scale_multiplier(scale);
+            return static_cast<ToFieldType>(value.value) /
+                   FromDataType::get_scale_multiplier(scale).value;
         }
     } else {
-        FromFieldType converted_value =
-                convert_decimals<FromDataType, FromDataType>(value, scale, 0);
-
-        if constexpr (sizeof(FromFieldType) > sizeof(ToFieldType) ||
-                      !std::numeric_limits<ToFieldType>::is_signed) {
-            if constexpr (std::numeric_limits<ToFieldType>::is_signed) {
-                if (converted_value < std::numeric_limits<ToFieldType>::min()) {
-                    VLOG_DEBUG << "Decimal convert overflow";
-                    return std::numeric_limits<ToFieldType>::min();
-                }
-                if (converted_value > std::numeric_limits<ToFieldType>::max()) {
-                    VLOG_DEBUG << "Decimal convert overflow";
-                    return std::numeric_limits<ToFieldType>::max();
-                }
-            } else {
-                using CastIntType =
-                        std::conditional_t<std::is_same_v<ToFieldType, UInt64>, Int128, Int64>;
-
-                if (converted_value < 0 ||
-                    converted_value >
-                            static_cast<CastIntType>(std::numeric_limits<ToFieldType>::max())) {
-                    VLOG_DEBUG << "Decimal convert overflow";
-                    return std::numeric_limits<ToFieldType>::max();
-                }
-            }
-        }
-        return converted_value;
+        return convert_decimals<FromDataType, FromDataType, false, narrow_integral>(
+                value, scale, 0, FromFieldType(min_result), FromFieldType(max_result));
     }
 }
 
-template <typename FromDataType, typename ToDataType>
+template <typename FromDataType, typename ToDataType, bool multiply_may_overflow,
+          bool narrow_integral>
     requires IsDataTypeNumber<FromDataType> && IsDataTypeDecimal<ToDataType>
 ToDataType::FieldType convert_to_decimal(const typename FromDataType::FieldType& value,
-                                         UInt32 scale, UInt8* overflow_flag) {
+                                         UInt32 from_scale, UInt32 to_scale,
+                                         const typename ToDataType::FieldType& min_result,
+                                         const typename ToDataType::FieldType& max_result) {
     using FromFieldType = typename FromDataType::FieldType;
-    using ToNativeType = typename ToDataType::FieldType::NativeType;
 
     if constexpr (std::is_floating_point_v<FromFieldType>) {
         if (!std::isfinite(value)) {
-            if (overflow_flag) {
-                *overflow_flag = 1;
-            }
             VLOG_DEBUG << "Decimal convert overflow. Cannot convert infinity or NaN to decimal";
-            return value < 0 ? std::numeric_limits<ToNativeType>::min()
-                             : std::numeric_limits<ToNativeType>::max();
+            throw Exception(ErrorCode::ARITHMETIC_OVERFLOW_ERRROR, "Arithmetic overflow");
         }
 
         FromFieldType out;
-        out = value * ToDataType::get_scale_multiplier(scale);
-        if (out <= static_cast<FromFieldType>(std::numeric_limits<ToNativeType>::min())) {
-            if (overflow_flag) {
-                *overflow_flag = 1;
-            }
+        out = value * ToDataType::get_scale_multiplier(to_scale);
+        if (out <= static_cast<FromFieldType>(-max_result) ||
+            out >= static_cast<FromFieldType>(max_result)) {
             VLOG_DEBUG << "Decimal convert overflow. Float is out of Decimal range";
-            return std::numeric_limits<ToNativeType>::min();
+            throw Exception(ErrorCode::ARITHMETIC_OVERFLOW_ERRROR, "Arithmetic overflow");
         }
-        if (out >= static_cast<FromFieldType>(std::numeric_limits<ToNativeType>::max())) {
-            if (overflow_flag) {
-                *overflow_flag = 1;
-            }
-            VLOG_DEBUG << "Decimal convert overflow. Float is out of Decimal range";
-            return std::numeric_limits<ToNativeType>::max();
-        }
-        return out;
+        return typename ToDataType::FieldType(out);
     } else {
         if constexpr (std::is_same_v<FromFieldType, UInt64>) {
             if (value > static_cast<UInt64>(std::numeric_limits<Int64>::max())) {
-                return convert_decimals<DataTypeDecimal<Decimal128>, ToDataType>(value, 0, scale);
+                return convert_decimals<DataTypeDecimal<Decimal128>, ToDataType,
+                                        multiply_may_overflow, narrow_integral>(
+                        value, from_scale, to_scale, min_result, max_result);
             }
         }
         if constexpr (std::is_same_v<FromFieldType, Int128>) {
-            return convert_decimals<DataTypeDecimal<Decimal128>, ToDataType>(value, 0, scale);
+            return convert_decimals<DataTypeDecimal<Decimal128>, ToDataType, multiply_may_overflow,
+                                    narrow_integral>(value, from_scale, to_scale, min_result,
+                                                     max_result);
         }
 
-        return convert_decimals<DataTypeDecimal<Decimal64>, ToDataType>(value, 0, scale);
+        return convert_decimals<DataTypeDecimal<Decimal64>, ToDataType, multiply_may_overflow,
+                                narrow_integral>(value, from_scale, to_scale, min_result,
+                                                 max_result);
     }
 }
 
