@@ -135,7 +135,8 @@ public:
 
     OrcReader(RuntimeProfile* profile, RuntimeState* state, const TFileScanRangeParams& params,
               const TFileRangeDesc& range, size_t batch_size, const std::string& ctz,
-              io::IOContext* io_ctx, bool enable_lazy_mat = true);
+              io::IOContext* io_ctx, bool enable_lazy_mat = true,
+              std::vector<orc::TypeKind>* unsupported_pushdown_types = nullptr);
 
     OrcReader(const TFileScanRangeParams& params, const TFileRangeDesc& range,
               const std::string& ctz, io::IOContext* io_ctx, bool enable_lazy_mat = true);
@@ -559,6 +560,7 @@ private:
     std::unique_ptr<orc::StringDictFilter> _string_dict_filter;
     bool _is_dict_cols_converted;
     bool _has_complex_type = false;
+    std::vector<orc::TypeKind>* _unsupported_pushdown_types;
 };
 
 class ORCFileInputStream : public orc::InputStream {
