@@ -140,7 +140,16 @@ public abstract class AlterHandler extends MasterDaemon {
     }
 
     public Long getAlterJobV2Num(org.apache.doris.alter.AlterJobV2.JobState state) {
-        return alterJobsV2.values().stream().filter(e -> e.getJobState() == state).count();
+        Long counter = 0L;
+
+        for (AlterJobV2 job : alterJobsV2.values()) {
+            // no need to check priv here. This method is only called in show proc stmt,
+            // which already check the ADMIN priv.
+            if (job.getJobState() == state) {
+                counter++;
+            }
+        }
+        return counter;
     }
 
     @Override
@@ -164,9 +173,18 @@ public abstract class AlterHandler extends MasterDaemon {
     /*
      * entry function. handle alter ops
      */
-    public abstract void process(List<AlterClause> alterClauses, String clusterName, Database db, OlapTable olapTable)
+    public abstract void process(String rawSql, List<AlterClause> alterClauses, String clusterName, Database db,
+                                 OlapTable olapTable)
             throws UserException;
 
+    /*
+     * entry function. handle alter ops
+     */
+    public void process(List<AlterClause> alterClauses, String clusterName, Database db, OlapTable olapTable)
+            throws UserException {
+        process("", alterClauses, clusterName, db, olapTable);
+    }
+
     /*
      * entry function. handle alter ops for external table
      */
