@@ -306,6 +306,9 @@ public class DecimalLiteral extends LiteralExpr {
             int integerPart = Math.max(this.value.precision() - this.value.scale(),
                     type.getPrecision() - ((ScalarType) type).decimalScale());
             this.type = ScalarType.createDecimalV3Type(integerPart + scale, scale);
+            BigDecimal adjustedValue = value.scale() < 0 ? value
+                    : value.setScale(scale, RoundingMode.HALF_UP);
+            this.value = Objects.requireNonNull(adjustedValue);
         }
     }
 
