@@ -147,15 +147,21 @@ public class SchemaTable extends Table {
                             .column("SCHEMA_NAME", ScalarType.createVarchar(32))
                             .column("DEFAULT_CHARACTER_SET_NAME", ScalarType.createVarchar(32))
                             .column("DEFAULT_COLLATION_NAME", ScalarType.createVarchar(32))
-                            .column("SQL_PATH", ScalarType.createVarchar(512)).build()))
+                            .column("SQL_PATH", ScalarType.createVarchar(512))
+                            .column("DEFAULT_ENCRYPTION", ScalarType.createVarchar(3)).build()))
             .put("session_variables",
                     new SchemaTable(SystemIdGenerator.getNextId(), "session_variables", TableType.SCHEMA,
                             builder().column("VARIABLE_NAME", ScalarType.createVarchar(64))
-                                    .column("VARIABLE_VALUE", ScalarType.createVarchar(1024)).build()))
+                                    .column("VARIABLE_VALUE", ScalarType.createVarchar(1024))
+                                    .column("DEFAULT_VALUE", ScalarType.createVarchar(1024))
+                                    .column("CHANGED", ScalarType.createVarchar(4))
+                                    .build()))
             .put("global_variables",
                     new SchemaTable(SystemIdGenerator.getNextId(), "global_variables", TableType.SCHEMA,
                             builder().column("VARIABLE_NAME", ScalarType.createVarchar(64))
-                                    .column("VARIABLE_VALUE", ScalarType.createVarchar(1024)).build()))
+                                    .column("VARIABLE_VALUE", ScalarType.createVarchar(1024))
+                                    .column("DEFAULT_VALUE", ScalarType.createVarchar(1024))
+                                    .column("CHANGED", ScalarType.createVarchar(4)).build()))
             .put("columns",
                     new SchemaTable(SystemIdGenerator.getNextId(), "columns", TableType.SCHEMA,
                             builder().column("TABLE_CATALOG", ScalarType.createVarchar(512))
@@ -245,10 +251,10 @@ public class SchemaTable extends Table {
             // Compatible with mysql for mysqldump
             .put("column_statistics",
                     new SchemaTable(SystemIdGenerator.getNextId(), "column_statistics", TableType.SCHEMA,
-                    builder().column("SCHEMA_NAME", ScalarType.createVarchar(64))
-                            .column("TABLE_NAME", ScalarType.createVarchar(64))
-                            .column("COLUMN_NAME", ScalarType.createVarchar(64))
-                            .column("HISTOGRAM", ScalarType.createJsonbType()).build()))
+                            builder().column("SCHEMA_NAME", ScalarType.createVarchar(64))
+                                    .column("TABLE_NAME", ScalarType.createVarchar(64))
+                                    .column("COLUMN_NAME", ScalarType.createVarchar(64))
+                                    .column("HISTOGRAM", ScalarType.createJsonbType()).build()))
             .put("files",
                     new SchemaTable(SystemIdGenerator.getNextId(), "files", TableType.SCHEMA,
                             builder().column("FILE_ID", ScalarType.createType(PrimitiveType.BIGINT))
@@ -379,37 +385,77 @@ public class SchemaTable extends Table {
                                     .column("COLLATION_CONNECTION", ScalarType.createVarchar(32))
                                     .column("DATABASE_COLLATION", ScalarType.createVarchar(32)).build()))
             .put("rowsets", new SchemaTable(SystemIdGenerator.getNextId(), "rowsets", TableType.SCHEMA,
-                            builder().column("BACKEND_ID", ScalarType.createType(PrimitiveType.BIGINT))
-                                    .column("ROWSET_ID", ScalarType.createVarchar(64))
-                                    .column("TABLET_ID", ScalarType.createType(PrimitiveType.BIGINT))
-                                    .column("ROWSET_NUM_ROWS", ScalarType.createType(PrimitiveType.BIGINT))
-                                    .column("TXN_ID", ScalarType.createType(PrimitiveType.BIGINT))
-                                    .column("NUM_SEGMENTS", ScalarType.createType(PrimitiveType.BIGINT))
-                                    .column("START_VERSION", ScalarType.createType(PrimitiveType.BIGINT))
-                                    .column("END_VERSION", ScalarType.createType(PrimitiveType.BIGINT))
-                                    .column("INDEX_DISK_SIZE", ScalarType.createType(PrimitiveType.BIGINT))
-                                    .column("DATA_DISK_SIZE", ScalarType.createType(PrimitiveType.BIGINT))
-                                    .column("CREATION_TIME", ScalarType.createType(PrimitiveType.BIGINT))
-                                    .column("NEWEST_WRITE_TIMESTAMP", ScalarType.createType(PrimitiveType.BIGINT))
-                                    .build()))
+                    builder().column("BACKEND_ID", ScalarType.createType(PrimitiveType.BIGINT))
+                            .column("ROWSET_ID", ScalarType.createVarchar(64))
+                            .column("TABLET_ID", ScalarType.createType(PrimitiveType.BIGINT))
+                            .column("ROWSET_NUM_ROWS", ScalarType.createType(PrimitiveType.BIGINT))
+                            .column("TXN_ID", ScalarType.createType(PrimitiveType.BIGINT))
+                            .column("NUM_SEGMENTS", ScalarType.createType(PrimitiveType.BIGINT))
+                            .column("START_VERSION", ScalarType.createType(PrimitiveType.BIGINT))
+                            .column("END_VERSION", ScalarType.createType(PrimitiveType.BIGINT))
+                            .column("INDEX_DISK_SIZE", ScalarType.createType(PrimitiveType.BIGINT))
+                            .column("DATA_DISK_SIZE", ScalarType.createType(PrimitiveType.BIGINT))
+                            .column("CREATION_TIME", ScalarType.createType(PrimitiveType.BIGINT))
+                            .column("NEWEST_WRITE_TIMESTAMP", ScalarType.createType(PrimitiveType.BIGINT))
+                            .build()))
             .put("parameters", new SchemaTable(SystemIdGenerator.getNextId(), "parameters", TableType.SCHEMA,
-                            builder().column("SPECIFIC_CATALOG", ScalarType.createVarchar(64))
-                                    .column("SPECIFIC_SCHEMA", ScalarType.createVarchar(64))
-                                    .column("SPECIFIC_NAME", ScalarType.createVarchar(64))
-                                    .column("ORDINAL_POSITION", ScalarType.createVarchar(77))
-                                    .column("PARAMETER_MODE", ScalarType.createVarchar(77))
-                                    .column("PARAMETER_NAME", ScalarType.createVarchar(77))
-                                    .column("DATA_TYPE", ScalarType.createVarchar(64))
-                                    .column("CHARACTER_OCTET_LENGTH", ScalarType.createVarchar(64))
-                                    .column("NUMERIC_PRECISION", ScalarType.createVarchar(512))
-                                    .column("NUMERIC_SCALE", ScalarType.createVarchar(64))
-                                    .column("DATETIME_PRECISION", ScalarType.createVarchar(64))
-                                    .column("CHARACTER_SET_NAME", ScalarType.createVarchar(256))
-                                    .column("COLLATION_NAME", ScalarType.createVarchar(64))
-                                    .column("DTD_IDENTIFIER", ScalarType.createVarchar(64))
-                                    .column("ROUTINE_TYPE", ScalarType.createVarchar(64))
-                                    .column("DATA_TYPEDTD_IDENDS", ScalarType.createVarchar(64))
-                                    .build()))
+                    builder().column("SPECIFIC_CATALOG", ScalarType.createVarchar(64))
+                            .column("SPECIFIC_SCHEMA", ScalarType.createVarchar(64))
+                            .column("SPECIFIC_NAME", ScalarType.createVarchar(64))
+                            .column("ORDINAL_POSITION", ScalarType.createVarchar(77))
+                            .column("PARAMETER_MODE", ScalarType.createVarchar(77))
+                            .column("PARAMETER_NAME", ScalarType.createVarchar(77))
+                            .column("DATA_TYPE", ScalarType.createVarchar(64))
+                            .column("CHARACTER_OCTET_LENGTH", ScalarType.createVarchar(64))
+                            .column("NUMERIC_PRECISION", ScalarType.createVarchar(512))
+                            .column("NUMERIC_SCALE", ScalarType.createVarchar(64))
+                            .column("DATETIME_PRECISION", ScalarType.createVarchar(64))
+                            .column("CHARACTER_SET_NAME", ScalarType.createVarchar(256))
+                            .column("COLLATION_NAME", ScalarType.createVarchar(64))
+                            .column("DTD_IDENTIFIER", ScalarType.createVarchar(64))
+                            .column("ROUTINE_TYPE", ScalarType.createVarchar(64))
+                            .column("DATA_TYPEDTD_IDENDS", ScalarType.createVarchar(64))
+                            .build()))
+            .put("metadata_name_ids", new SchemaTable(SystemIdGenerator.getNextId(),
+                        "metadata_name_ids", TableType.SCHEMA,
+                    builder().column("CATALOG_ID", ScalarType.createType(PrimitiveType.BIGINT))
+                            .column("CATALOG_NAME", ScalarType.createVarchar(FN_REFLEN))
+                            .column("DATABASE_ID", ScalarType.createType(PrimitiveType.BIGINT))
+                            .column("DATABASE_NAME", ScalarType.createVarchar(NAME_CHAR_LEN))
+                            .column("TABLE_ID", ScalarType.createType(PrimitiveType.BIGINT))
+                            .column("TABLE_NAME", ScalarType.createVarchar(NAME_CHAR_LEN))
+                            .build()))
+            .put("profiling", new SchemaTable(SystemIdGenerator.getNextId(), "profiling", TableType.SCHEMA,
+                    builder().column("QUERY_ID", ScalarType.createType(PrimitiveType.INT))
+                            .column("SEQ", ScalarType.createType(PrimitiveType.INT))
+                            .column("STATE", ScalarType.createVarchar(30))
+                            .column("DURATION", ScalarType.createType(PrimitiveType.DOUBLE))
+                            .column("CPU_USER", ScalarType.createType(PrimitiveType.DOUBLE))
+                            .column("CPU_SYSTEM", ScalarType.createType(PrimitiveType.DOUBLE))
+                            .column("CONTEXT_VOLUNTARY", ScalarType.createType(PrimitiveType.INT))
+                            .column("CONTEXT_INVOLUNTARY", ScalarType.createType(PrimitiveType.INT))
+                            .column("BLOCK_OPS_IN", ScalarType.createType(PrimitiveType.INT))
+                            .column("BLOCK_OPS_OUT", ScalarType.createType(PrimitiveType.INT))
+                            .column("MESSAGES_SENT", ScalarType.createType(PrimitiveType.INT))
+                            .column("MESSAGES_RECEIVED", ScalarType.createType(PrimitiveType.INT))
+                            .column("PAGE_FAULTS_MAJOR", ScalarType.createType(PrimitiveType.INT))
+                            .column("PAGE_FAULTS_MINOR", ScalarType.createType(PrimitiveType.INT))
+                            .column("SWAPS", ScalarType.createType(PrimitiveType.INT))
+                            .column("SOURCE_FUNCTION", ScalarType.createVarchar(30))
+                            .column("SOURCE_FILE", ScalarType.createVarchar(20))
+                            .column("SOURCE_LINE", ScalarType.createType(PrimitiveType.INT))
+                            .build()))
+            .put("processlist", new SchemaTable(SystemIdGenerator.getNextId(), "processlist", TableType.SCHEMA,
+                    builder().column("ID", ScalarType.createType(PrimitiveType.LARGEINT))
+                            .column("USER", ScalarType.createVarchar(32))
+                            .column("HOST", ScalarType.createVarchar(261))
+                            .column("CATALOG", ScalarType.createVarchar(64))
+                            .column("DB", ScalarType.createVarchar(64))
+                            .column("COMMAND", ScalarType.createVarchar(16))
+                            .column("TIME", ScalarType.createType(PrimitiveType.INT))
+                            .column("STATE", ScalarType.createVarchar(64))
+                            .column("INFO", ScalarType.createVarchar(ScalarType.MAX_VARCHAR_LENGTH))
+                            .build()))
             .build();
 
     protected SchemaTable(long id, String name, TableType type, List<Column> baseSchema) {
