@@ -31,6 +31,7 @@ import org.apache.logging.log4j.Logger;
 import org.apache.paimon.schema.TableSchema;
 import org.apache.paimon.table.AbstractFileStoreTable;
 import org.apache.paimon.table.Table;
+import org.apache.paimon.table.source.Split;
 import org.apache.paimon.types.ArrayType;
 import org.apache.paimon.types.DataField;
 import org.apache.paimon.types.DecimalType;
@@ -154,4 +155,20 @@ public class PaimonExternalTable extends ExternalTable {
                     + getPaimonCatalogType());
         }
     }
+
+    @Override
+    public long fetchRowCount() {
+        makeSureInitialized();
+        try {
+            long rowCount = 0;
+            List<Split> splits = originTable.newReadBuilder().newScan().plan().splits();
+            for (Split split : splits) {
+                rowCount += split.rowCount();
+            }
+            return rowCount;
+        } catch (Exception e) {
+            LOG.warn("Fail to collect row count for db {} table {}", dbName, name, e);
+        }
+        return -1;
+    }
 }
