@@ -45,6 +45,11 @@ public class JdbcOracleClient extends JdbcClient {
         return conn.getCatalog();
     }
 
+    @Override
+    public String getTestQuery() {
+        return "SELECT 1 FROM dual";
+    }
+
     @Override
     public List<String> getDatabaseNameList() {
         Connection conn = getConnection();
