@@ -47,7 +47,10 @@ public interface Journal {
     public JournalCursor read(long fromKey, long toKey);
 
     // Write a journal and sync to disk
-    public void write(short op, Writable writable) throws IOException;
+    public long write(short op, Writable writable) throws IOException;
+
+    // Get current journal number
+    public long getJournalNum();
 
     // Delete journals whose max id is less than deleteToJournalId
     public void deleteJournals(long deleteJournalToId);
