@@ -60,11 +60,13 @@ import org.apache.doris.plugin.AuditEvent.EventType;
 import org.apache.doris.proto.Data;
 import org.apache.doris.qe.QueryState.MysqlStateType;
 import org.apache.doris.service.FrontendOptions;
+import org.apache.doris.thrift.TExprNode;
 import org.apache.doris.thrift.TMasterOpRequest;
 import org.apache.doris.thrift.TMasterOpResult;
 import org.apache.doris.thrift.TUniqueId;
 
 import com.google.common.base.Strings;
+import com.google.common.collect.Maps;
 import io.opentelemetry.api.trace.Span;
 import io.opentelemetry.api.trace.SpanContext;
 import io.opentelemetry.api.trace.SpanKind;
@@ -74,6 +76,7 @@ import io.opentelemetry.context.propagation.TextMapGetter;
 import org.apache.commons.codec.digest.DigestUtils;
 import org.apache.logging.log4j.LogManager;
 import org.apache.logging.log4j.Logger;
+import org.apache.thrift.TException;
 
 import java.io.IOException;
 import java.io.StringReader;
@@ -642,17 +645,16 @@ public class ConnectProcessor {
             } else {
                 executor.sendResultSet(resultSet);
                 packet = getResultPacket();
-                if (packet == null) {
-                    LOG.debug("packet == null");
-                    return;
-                }
             }
         } else {
             packet = getResultPacket();
-            if (packet == null) {
+        }
+
+        if (packet == null) {
+            if (LOG.isDebugEnabled()) {
                 LOG.debug("packet == null");
-                return;
             }
+            return;
         }
 
         MysqlChannel channel = ctx.getMysqlChannel();
@@ -672,7 +674,7 @@ public class ConnectProcessor {
         }
     }
 
-    public TMasterOpResult proxyExecute(TMasterOpRequest request) {
+    public TMasterOpResult proxyExecute(TMasterOpRequest request) throws TException {
         ctx.setDatabase(request.db);
         ctx.setQualifiedUser(request.user);
         ctx.setEnv(Env.getCurrentEnv());
@@ -729,6 +731,9 @@ public class ConnectProcessor {
                 ctx.getSessionVariable().setQueryTimeoutS(request.getQueryTimeout());
             }
         }
+        if (request.isSetUserVariables()) {
+            ctx.setUserVars(userVariableFromThrift(request.getUserVariables()));
+        }
 
         Map<String, String> traceCarrier = new HashMap<>();
         if (request.isSetTraceCarrier()) {
@@ -744,7 +749,6 @@ public class ConnectProcessor {
         if (Span.fromContext(extractedContext).getSpanContext().isValid()) {
             ctx.initTracer("master trace");
         }
-
         ctx.setThreadLocalInfo();
         StmtExecutor executor = null;
         try {
@@ -865,6 +869,20 @@ public class ConnectProcessor {
             }
         }
     }
+
+    private Map<String, LiteralExpr> userVariableFromThrift(Map<String, TExprNode> thriftMap) throws TException {
+        try {
+            Map<String, LiteralExpr> userVariables = Maps.newHashMap();
+            for (Map.Entry<String, TExprNode> entry : thriftMap.entrySet()) {
+                TExprNode tExprNode = entry.getValue();
+                LiteralExpr literalExpr = LiteralExpr.getLiteralExprFromThrift(tExprNode);
+                userVariables.put(entry.getKey(), literalExpr);
+            }
+            return userVariables;
+        } catch (AnalysisException e) {
+            throw new TException(e.getMessage());
+        }
+    }
 }
 
 
