@@ -22,6 +22,8 @@ import org.apache.doris.thrift.TStorageMedium;
 
 import com.google.common.collect.ImmutableCollection;
 import com.google.common.collect.Sets;
+import org.apache.logging.log4j.LogManager;
+import org.apache.logging.log4j.Logger;
 
 import java.util.ArrayList;
 import java.util.Collections;
@@ -33,7 +35,7 @@ import java.util.stream.Collectors;
  * Selection policy for building BE nodes
  */
 public class BeSelectionPolicy {
-    public String cluster = SystemInfoService.DEFAULT_CLUSTER;
+    private static final Logger LOG = LogManager.getLogger(BeSelectionPolicy.class);
     public boolean needScheduleAvailable = false;
     public boolean needQueryAvailable = false;
     public boolean needLoadAvailable = false;
@@ -49,6 +51,8 @@ public class BeSelectionPolicy {
     public boolean preferComputeNode = false;
     public int expectBeNum = 0;
 
+    public List<String> preferredLocations = new ArrayList<>();
+
     private BeSelectionPolicy() {
 
     }
@@ -60,11 +64,6 @@ public class BeSelectionPolicy {
             policy = new BeSelectionPolicy();
         }
 
-        public Builder setCluster(String cluster) {
-            policy.cluster = cluster;
-            return this;
-        }
-
         public Builder needScheduleAvailable() {
             policy.needScheduleAvailable = true;
             return this;
@@ -110,6 +109,11 @@ public class BeSelectionPolicy {
             return this;
         }
 
+        public Builder addPreLocations(List<String> preferredLocations) {
+            policy.preferredLocations.addAll(preferredLocations);
+            return this;
+        }
+
         public BeSelectionPolicy build() {
             return policy;
         }
@@ -118,6 +122,9 @@ public class BeSelectionPolicy {
     private boolean isMatch(Backend backend) {
         // Compute node is only used when preferComputeNode is set.
         if (!preferComputeNode && backend.isComputeNode()) {
+            if (LOG.isDebugEnabled()) {
+                LOG.debug("Backend [{}] is not match by ComputeNode rule, policy: [{}]", backend.getHost(), this);
+            }
             return false;
         }
 
@@ -125,14 +132,25 @@ public class BeSelectionPolicy {
                 || needLoadAvailable && !backend.isLoadAvailable() || !resourceTags.isEmpty() && !resourceTags.contains(
                 backend.getLocationTag()) || storageMedium != null && !backend.hasSpecifiedStorageMedium(
                 storageMedium)) {
+            if (LOG.isDebugEnabled()) {
+                LOG.debug("Backend [{}] is not match by Other rules, policy: [{}]", backend.getHost(), this);
+            }
             return false;
         }
 
         if (checkDiskUsage) {
             if (storageMedium == null && backend.diskExceedLimit()) {
+                if (LOG.isDebugEnabled()) {
+                    LOG.debug("Backend [{}] is not match by diskExceedLimit rule, policy: [{}]", backend.getHost(),
+                            this);
+                }
                 return false;
             }
             if (storageMedium != null && backend.diskExceedLimitByStorageMedium(storageMedium)) {
+                if (LOG.isDebugEnabled()) {
+                    LOG.debug("Backend [{}] is not match by diskExceedLimitByStorageMedium rule, policy: [{}]",
+                            backend.getHost(), this);
+                }
                 return false;
             }
         }
@@ -141,6 +159,13 @@ public class BeSelectionPolicy {
 
     public List<Backend> getCandidateBackends(ImmutableCollection<Backend> backends) {
         List<Backend> filterBackends = backends.stream().filter(this::isMatch).collect(Collectors.toList());
+        List<Backend> preLocationFilterBackends = filterBackends.stream()
+                .filter(iterm -> preferredLocations.contains(iterm.getHost())).collect(Collectors.toList());
+        // If preLocations were chosen, use the preLocation backends. Otherwise we just ignore this filter.
+        if (!preLocationFilterBackends.isEmpty()) {
+            filterBackends = preLocationFilterBackends;
+        }
+        Collections.shuffle(filterBackends);
         List<Backend> candidates = new ArrayList<>();
         if (preferComputeNode) {
             int num = 0;
@@ -172,14 +197,8 @@ public class BeSelectionPolicy {
 
     @Override
     public String toString() {
-        StringBuilder sb = new StringBuilder();
-        sb.append("cluster|query|load|schedule|tags|medium: ");
-        sb.append(cluster).append("|");
-        sb.append(needQueryAvailable).append("|");
-        sb.append(needLoadAvailable).append("|");
-        sb.append(needScheduleAvailable).append("|");
-        sb.append(resourceTags).append("|");
-        sb.append(storageMedium);
-        return sb.toString();
+        return String.format("computeNode=%s | query=%s | load=%s | schedule=%s | tags=%s | medium=%s",
+                preferComputeNode, needQueryAvailable, needLoadAvailable, needScheduleAvailable,
+                resourceTags.stream().map(tag -> tag.toString()).collect(Collectors.joining(",")), storageMedium);
     }
 }
