@@ -17,9 +17,10 @@
 
 package org.apache.doris.analysis;
 
+import org.apache.doris.catalog.TableIf.TableType;
 import org.apache.doris.common.AnalysisException;
+import org.apache.doris.mysql.privilege.AccessControllerManager;
 import org.apache.doris.mysql.privilege.MockedAuth;
-import org.apache.doris.mysql.privilege.PaloAuth;
 import org.apache.doris.qe.ConnectContext;
 
 import mockit.Mocked;
@@ -31,14 +32,14 @@ public class ShowTableStmtTest {
     private Analyzer analyzer;
 
     @Mocked
-    private PaloAuth auth;
+    private AccessControllerManager accessManager;
     @Mocked
     private ConnectContext ctx;
 
     @Before
     public void setUp() {
         analyzer = AccessTestUtil.fetchAdminAnalyzer(true);
-        MockedAuth.mockedAuth(auth);
+        MockedAuth.mockedAccess(accessManager);
         MockedAuth.mockedConnectContext(ctx, "root", "192.168.1.1");
     }
 
@@ -68,6 +69,28 @@ public class ShowTableStmtTest {
         Assert.assertEquals("Table_type", stmt.getMetaData().getColumn(1).getName());
     }
 
+    @Test
+    public void testShowViews() throws AnalysisException {
+        ShowTableStmt stmt = new ShowTableStmt("", null, false, TableType.VIEW,
+                null, null);
+        stmt.analyze(analyzer);
+        Assert.assertEquals("SHOW VIEWS FROM internal.testDb", stmt.toString());
+        Assert.assertEquals("testCluster:testDb", stmt.getDb());
+        Assert.assertEquals(TableType.VIEW, stmt.getType());
+        Assert.assertFalse(stmt.isVerbose());
+        Assert.assertEquals(1, stmt.getMetaData().getColumnCount());
+        Assert.assertEquals("Tables_in_testDb", stmt.getMetaData().getColumn(0).getName());
+
+        stmt = new ShowTableStmt("abc", null, true, TableType.VIEW, "bcd", null);
+        stmt.analyze(analyzer);
+        Assert.assertEquals("bcd", stmt.getPattern());
+        Assert.assertEquals("SHOW FULL VIEWS FROM internal.abc LIKE 'bcd'", stmt.toString());
+        Assert.assertEquals(3, stmt.getMetaData().getColumnCount());
+        Assert.assertEquals("Tables_in_abc", stmt.getMetaData().getColumn(0).getName());
+        Assert.assertEquals("Table_type", stmt.getMetaData().getColumn(1).getName());
+        Assert.assertEquals(TableType.VIEW, stmt.getType());
+    }
+
     @Test(expected = AnalysisException.class)
     public void testNoDb() throws AnalysisException {
         ShowTableStmt stmt = new ShowTableStmt("", null, false, null);
