@@ -321,7 +321,7 @@ public class TabletRepairAndBalanceTest {
         Assert.assertEquals(tag2, be.getLocationTag());
         ExceptionChecker.expectThrows(UserException.class, () -> tbl.checkReplicaAllocation());
         checkTableReplicaAllocation(tbl);
-        Assert.assertEquals(90, replicaMetaTable.cellSet().size());
+        Assert.assertEquals(90, invertedIndex.getReplicaMetaTable().cellSet().size());
 
         // For now, Backends:
         // [0, 1]:      zone1
@@ -417,7 +417,7 @@ public class TabletRepairAndBalanceTest {
         ExceptionChecker.expectThrowsNoException(() -> dropTable(dropStmt1));
         ExceptionChecker.expectThrowsNoException(() -> dropTable(dropStmt2));
         ExceptionChecker.expectThrowsNoException(() -> dropTable(dropStmt3));
-        Assert.assertEquals(0, replicaMetaTable.size());
+        Assert.assertEquals(0, invertedIndex.getReplicaMetaTable().size());
 
         // set all backends' tag to default
         for (int i = 0; i < backends.size(); ++i) {
