@@ -265,16 +265,19 @@ class PlanEqualsTest {
 
         PhysicalOlapScan actual = new PhysicalOlapScan(id, olapTable, Lists.newArrayList("a"),
                 1L, selectedTabletId, olapTable.getPartitionIds(), distributionSpecHash,
-                PreAggStatus.on(), ImmutableList.of(), Optional.empty(), logicalProperties);
+                PreAggStatus.on(), ImmutableList.of(), Optional.empty(), logicalProperties,
+                Optional.empty());
 
         PhysicalOlapScan expected = new PhysicalOlapScan(id, olapTable, Lists.newArrayList("a"),
                 1L, selectedTabletId, olapTable.getPartitionIds(), distributionSpecHash,
-                PreAggStatus.on(), ImmutableList.of(), Optional.empty(), logicalProperties);
+                PreAggStatus.on(), ImmutableList.of(), Optional.empty(), logicalProperties,
+                Optional.empty());
         Assertions.assertEquals(expected, actual);
 
         PhysicalOlapScan unexpected = new PhysicalOlapScan(id, olapTable, Lists.newArrayList("b"),
                 12345L, selectedTabletId, olapTable.getPartitionIds(), distributionSpecHash,
-                PreAggStatus.on(), ImmutableList.of(), Optional.empty(), logicalProperties);
+                PreAggStatus.on(), ImmutableList.of(), Optional.empty(), logicalProperties,
+                Optional.empty());
         Assertions.assertNotEquals(unexpected, actual);
     }
 
